@@ -5,7 +5,7 @@ use warnings;
 use warnings::register;
 
 use vars '$VERSION';
-$VERSION = do { my @r = ( q$Revision: 2.73 $ =~ /\d+/g ); sprintf "%d." . "%03d" x $#r, @r };
+$VERSION = do { my @r = ( q$Revision: 2.74 $ =~ /\d+/g ); sprintf "%d." . "%03d" x $#r, @r };
 
 
 =head1 NAME
@@ -40,20 +40,21 @@ BEGIN {
 	eval { require Log::Log4perl; };
 	if($@) {
 		no strict qw(refs);
-		*{__PACKAGE__."::$_"} = sub { } for qw(TRACE DEBUG INFO WARN ERROR FATAL);
+		*{"Tk::Wizard::$_"} = sub { } for qw(TRACE DEBUG INFO WARN ERROR FATAL);
+		if (__PACKAGE__ ne 'Tk::Wizard'){
+			*{__PACKAGE__."::$_"} = sub { } for qw(TRACE DEBUG INFO WARN ERROR FATAL);
+		}
 	} else {
 		no warnings;
 		require Log::Log4perl::Level;
 		Log::Log4perl::Level->import(__PACKAGE__);
 		Log::Log4perl->import(":easy");
 	}
-}
 
-BEGIN {
     require Exporter;    # Exporting Tk's MainLoop so that
     @ISA    = ( "Exporter", );    # I can just use strict and Tk::Wizard without
     @EXPORT = ("MainLoop");       # having to use Tk
-}    # end of BEGIN block
+}
 
 use base qw[ Tk::Derived Tk::Toplevel ];
 Tk::Widget->Construct('Wizard');
@@ -765,14 +766,14 @@ sub render_current_page {
     $self->_pack_forget( $self->{tagtext} );
     if ( !$self->_showing_side_banner ) {
         $self->_maybe_pack_tag_text;
-    }    # if
+    }
     if ( $self->_on_first_page || $self->_on_last_page ) {
         $self->{left_object}->pack( -side => "left", -anchor => "n", -fill => 'y' );
         if ( $self->{-style} ne '95' ) {
             $frame_pack{-expand} = 1;
             $frame_pack{-fill}   = 'both';
         }
-    }    # if
+    }
     elsif ( $self->cget( -style ) eq 'top' ) {
         $self->_pack_forget( $self->{left_object} );
     }
